@@ -5,6 +5,7 @@ Possible destinations: PYPI.
 import subprocess
 import os
 import mylogging
+import shutil
 
 from . import misc
 
@@ -26,7 +27,18 @@ def deploy_to_pypi(setup_path=None):
 
     setup_path = misc.root_path if not setup_path else setup_path
 
-    subprocess.run(['python', 'setup.py', 'sdist', 'bdist_wheel'], cwd=misc.root_path, shell=True, check=True)
+    setup_py_path = setup_path / 'setup.py'
 
-    # TODO move to separate  folder (dist name conflict) and clean afterwards
-    subprocess.run(['twine', 'upload', '-u', os.environ['TWINE_USERNAME'], '-p', os.environ['TWINE_PASSWORD'], 'dist/*'], cwd=misc.root_path, shell=True, check=True)
+    if not setup_py_path.exists():
+        setup_py_path = misc.find_path('setup.py', exclude=['node_modules'])
+        setup_path = setup_py_path.parent
+
+        if not (setup_path / 'setup.py').exists():
+            raise FileNotFoundError(mylogging.return_str("Setup.py file not found. Setup `setup_path` param."))
+
+    subprocess.run(['python', 'setup.py', 'sdist', 'bdist_wheel'], cwd=setup_path, shell=True, check=True)
+
+    subprocess.run(['twine', 'upload', '-u', os.environ['TWINE_USERNAME'], '-p', os.environ['TWINE_PASSWORD'], 'dist/*'], cwd=setup_path, shell=True, check=True)
+
+    shutil.rmtree(root_path / 'tests' / 'build')
+    shutil.rmtree(root_path / 'tests' / 'dist')
